package cn.com.ty.lift.system.user.controller;

import cn.com.ty.lift.common.constants.ApiConstants;
import cn.com.ty.lift.system.user.dao.entity.UserAccount;
import cn.com.ty.lift.system.user.dao.entity.UserRole;
import cn.com.ty.lift.system.user.dao.entity.model.RoleRequest;
import cn.com.ty.lift.system.user.service.IRoleService;
import cn.com.xwy.boot.web.dto.RestResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;

/**
 * @author huangyuan
 * @date 2019-12-01
 * @description 角色管理
 */
@RestController
@RequestMapping("/role")
public class RoleController {

    @Autowired
    private IRoleService roleService;

    /**
     * @description 获取角色列表
     * @date 2019/11/27 10:03 AM
     * @param roleRequest 角色请求类
     * @return
     */
    @RequestMapping("/list")
    public RestResponse list(RoleRequest roleRequest){
        return roleService.list(roleRequest);
    }

    /**
     * @description 添加角色
     * @date 2019/11/27 10:03 AM
     * @param request http请求对象
     * @param roleRequest 角色请求对象
     * @return
     */
    @PostMapping("/add")
    public RestResponse addRole(HttpServletRequest request, @RequestBody RoleRequest roleRequest){
        //设置创建者信息
        UserAccount userAccount = (UserAccount) request.getSession().getAttribute(ApiConstants.CURRENT_USER);
        roleRequest.setCreateUserId(userAccount.getUserId());
        return roleService.addRole(roleRequest);
    }

    /**
     * @description 添加角色
     * @date 2019/11/27 10:03 AM
     * @param request http请求对象
     * @param roleRequest 角色请求对象
     * @return
     */
    @PostMapping("/update")
    public RestResponse updateRole(HttpServletRequest request, @RequestBody RoleRequest roleRequest){
        //设置更新者信息
        UserAccount userAccount = (UserAccount) request.getSession().getAttribute(ApiConstants.CURRENT_USER);
        roleRequest.setUpdateUserId(userAccount.getUserId());
        return roleService.updateRole(roleRequest);
    }

    /**
     * @description 删除角色信息
     * @date 2019/11/27 10:03 AM
     * @param request http请求对象
     * @param roleRequest 角色请求类
     * @return
     */
    @PostMapping("/delete")
    public RestResponse deleteRole(HttpServletRequest request, @RequestBody RoleRequest roleRequest){
        //设置删除者信息
        UserAccount userAccount = (UserAccount) request.getSession().getAttribute(ApiConstants.CURRENT_USER);
        roleRequest.setDeleteUserId(userAccount.getUserId());
        return roleService.deleteRole(roleRequest);
    }

    /**
     * @description 通过用户id获取用户对应的菜单信息
     * @date 2019/11/27 10:03 AM
     * @param userRole 用户id和公司id
     * @return
     */
    @RequestMapping("/getUserMenus")
    public RestResponse getUserMenus(UserRole userRole){
        return roleService.getUserMenus(userRole);
    }

}
